@@ -1,5 +1,5 @@
 #ifndef __SGUARDDB_H
-#include <db.h>
+#include BDB_HEADER_PATH(db.h)
 
 typedef struct sg_db{
   DB_ENV *env_db;
@@ -7,7 +7,7 @@ typedef struct sg_db{
   DB *urls_db;
   char *db_home;
   char *domains_db_name;
-  char *urls_db_name;   
+  char *urls_db_name;
 } sg_db_t;
 
 
