@@ -606,7 +606,7 @@ static void build_icap_reply_headers(ci_request_t *req)
      const struct profile *profile = uc->profile;
      const struct cfg_action *cfg_action = uc->cfg_action;
      int addDefaultXHeaders = 1;
-     char buf[1024];
+     char buf[1040];
 
      if (cfg_action && !cfg_action->defaultXHeaders)
           addDefaultXHeaders = 0;
@@ -743,7 +743,7 @@ int url_check_check_preview(char *preview_data, int preview_data_len,
              Allocate a new body for it
            */
           if (ci_req_hasbody(req)) {
-              if (ci_allow206(req)) {
+              if (ci_req_allow206(req)) {
                   ci_request_206_origin_body(req, 0);
                   return CI_MOD_ALLOW206;
               }
@@ -753,7 +753,7 @@ int url_check_check_preview(char *preview_data, int preview_data_len,
           }
      }
 
-     unlock_data(req);
+     ci_req_unlock_data(req);
      return CI_MOD_CONTINUE;
 }
 
